@@ -1,8 +1,8 @@
 from geofound.models import create_foundation, create_soil
 # from geofound.stiffness import *
-from . import stiffness, damping
+from . import stiffness, damping, fadums_chart
 from geofound.checking_tools import isclose
 from geofound.capacity import *
 from geofound.settlement import *
 from geofound.exceptions import DesignError
-from geofound import models
\ No newline at end of file
+from geofound import models
